==> 0.1.2.tar.gz: lib/src/theme/data_table/data_table.dart <==
library basic_data_table;

import 'dart:async';

import 'package:basic_flutter_theme/src/responsive/responsive.dart';
import 'package:basic_flutter_theme/src/styles/styles.dart';
import 'package:basic_flutter_theme/src/theme/buttons/buttons.dart';
import 'package:basic_flutter_theme/src/theme/inputs/inputs.dart';
import 'package:basic_flutter_theme/src/utils/utils.dart';
import 'package:basic_flutter_theme/src/theme/measure_size.dart';
import 'package:basic_flutter_theme/src/theme/popup_menu_button/popup_menu_button.dart';
import 'package:basic_flutter_theme/src/theme/scrolls/scrolls.dart';
import 'package:basic_flutter_theme/src/theme/spaces.dart';
import 'package:eva_icons_flutter/eva_icons_flutter.dart';
import 'package:flutter/material.dart';

part 'common.dart';
part 'controller.dart';
part 'models/data_table_addition_column.dart';
part 'models/data_table_column.dart';
part 'models/data_table_option_ui.dart';
part 'models/data_table_pagination.dart';
part 'models/define_function.dart';
part 'state.dart';
part 'view.dart';
part 'widgets/checkbox_column.dart';
part 'widgets/checkbox_row_item.dart';
part 'widgets/content.dart';
part 'widgets/default_data_table.dart';
part 'widgets/fixed_column.dart';
part 'widgets/fixed_column_content.dart';
part 'widgets/fixed_column_header.dart';
part 'widgets/fixed_data_table.dart';
part 'widgets/header.dart';
part 'widgets/header_item.dart';
part 'widgets/pagination.dart';
part 'widgets/loading.dart';
part 'widgets/row.dart';
part 'widgets/row_item.dart';

==> 0.1.6.tar.gz: lib/src/theme/data_table/data_table.dart <==
library basic_data_table;

import 'dart:async';
import 'dart:math';

import 'package:basic_flutter_theme/src/responsive/responsive.dart';
import 'package:basic_flutter_theme/src/styles/styles.dart';
import 'package:basic_flutter_theme/src/theme/buttons/buttons.dart';
import 'package:basic_flutter_theme/src/theme/inputs/inputs.dart';
import 'package:basic_flutter_theme/src/utils/utils.dart';
import 'package:basic_flutter_theme/src/theme/measure_size.dart';
import 'package:basic_flutter_theme/src/theme/popup_menu_button/popup_menu_button.dart';
import 'package:basic_flutter_theme/src/theme/scrolls/scrolls.dart';
import 'package:basic_flutter_theme/src/theme/spaces.dart';
import 'package:eva_icons_flutter/eva_icons_flutter.dart';
import 'package:flutter/material.dart';

part 'common.dart';
part 'controller.dart';
part 'models/data_table_addition_column.dart';
part 'models/data_table_column.dart';
part 'models/data_table_option_ui.dart';
part 'models/data_table_pagination.dart';
part 'models/define_function.dart';
part 'state.dart';
part 'view.dart';
part 'widgets/checkbox_column.dart';
part 'widgets/checkbox_row_item.dart';
part 'widgets/content.dart';
part 'widgets/default_data_table.dart';
part 'widgets/fixed_column.dart';
part 'widgets/fixed_column_content.dart';
part 'widgets/fixed_column_fixed_table.dart';
part 'widgets/fixed_data_table.dart';
part 'widgets/header.dart';
part 'widgets/header_item.dart';
part 'widgets/pagination.dart';
part 'widgets/loading.dart';
part 'widgets/row.dart';
part 'widgets/row_item.dart';
